@@ -59,8 +59,7 @@ class KeycloackOpenIDConnectMock(KeycloakOpenIDConnect):
         user_info: Dict = USER_INFO,
         raw_realm_public_key: str = RAW_REALM_PUBLIC_KEY,
     ):
-        """Constructor
-        """
+        """Constructor"""
         super().__init__(
             server_url=server_url, realm_name=realm_name, client_id=client_id
         )
@@ -69,7 +68,7 @@ class KeycloackOpenIDConnectMock(KeycloakOpenIDConnect):
         self.realm_permissions = realm_permissions
         self.client_permissions = client_permissions
         self._keycloak.public_key = lambda: raw_realm_public_key
-        self._keycloak.well_know = lambda: {
+        self._keycloak.well_known = lambda: {
             "issuer": f"{self.server_url}realms/{self.realm_name}",
             "authorization_endpoint": (
                 f"{self.server_url}realms/"
@@ -100,6 +99,9 @@ class KeycloackOpenIDConnectMock(KeycloakOpenIDConnect):
                 "protocol/openid-connect/certs"
             ),
         }
+        # for python-keycloak < 1.0.0:
+        self._keycloak.well_know = self._keycloak.well_known
+
         self.set_auth_success(auth_success, oidc_profile, user_info)
 
     def decode_token(self, token):
@@ -182,7 +184,7 @@ def keycloak_oidc_factory(
     raw_realm_public_key: str = RAW_REALM_PUBLIC_KEY,
 ):
     """Keycloak mock fixture factory. Report to
-       :py:class:`swh.auth.pytest_plugin.KeycloackOpenIDConnectMock` docstring.
+    :py:class:`swh.auth.pytest_plugin.KeycloackOpenIDConnectMock` docstring.
 
     """
 
@@ -213,7 +215,9 @@ keycloak_mock_factory = keycloak_oidc_factory
 # (cf. test_keycloak.py, test_utils.py, django related tests)
 # or external modules using that pytest plugin
 _keycloak_oidc = keycloak_oidc_factory(
-    server_url=SERVER_URL, realm_name=REALM_NAME, client_id=CLIENT_ID,
+    server_url=SERVER_URL,
+    realm_name=REALM_NAME,
+    client_id=CLIENT_ID,
 )
 
 
